@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dylan" "0.2.0"
+(define-package "dylan" "20250319.1925"
   "Dylan editing modes."
   '((emacs "25.1"))
   :url "https://opendylan.org/"
-  :commit "c22f339b5394d26af4961192825e58ae766965ec"
-  :revdesc "c22f339b5394")
+  :commit "342d86a58ad307a581fc95c0f271661444dbc13c"
+  :revdesc "342d86a58ad3")
